# Dynamics-aware Evolutionary Profiling Uncouples Structural Rigidity from Functional Motion to Enable Enhanced Variant Interpretation

The identification of dynamic-conserved residues via the Dynamics-aware Evolutionary Profiling may fundamentally expand the boundaries of the druggable proteome and improve the resolution of genetic and evolutionary data.

This repository contains the source code and datasets for the large-scale statistical analysis presented in the manuscript. It encompasses the processing, scoring, and benchmarking of across two distinct cohorts.

We also provide an open-access web interface, https://www.karagolresearch.com/adept

## Citation
If you use this framework in your research, please cite:

* Karagöl, T., & Karagöl, A. (2026). Dynamics-aware Evolutionary Profiling Uncouples Structural Rigidity from Functional Motion to Enable Enhanced Variant Interpretation.

### License
This project is licensed under the MIT License - see the LICENSE file for details.
